pub async fn remove_project(
__arg0: State<AppState>,
__arg1: Json<SwitchProjectRequest>,
) -> impl IntoResponseExpand description
Remove a project from the Dashboard and global registry DELETE /api/projects
pub async fn remove_project(
__arg0: State<AppState>,
__arg1: Json<SwitchProjectRequest>,
) -> impl IntoResponseRemove a project from the Dashboard and global registry DELETE /api/projects