pub struct WebSocketState {
pub mcp_connections: Arc<RwLock<HashMap<String, McpConnection>>>,
pub ui_connections: Arc<RwLock<Vec<UiConnection>>>,
}Expand description
Shared WebSocket state
Fields
mcp_connections: Arc<RwLock<HashMap<String, McpConnection>>>Project path → MCP connection
ui_connections: Arc<RwLock<Vec<UiConnection>>>List of active UI connections
Implementations
Sourceimpl WebSocketState
impl WebSocketState
pub fn new() -> Self
Sourcepub async fn broadcast_to_ui(&self, message: &str)
pub async fn broadcast_to_ui(&self, message: &str)
Broadcast message to all UI connections
Sourcepub async fn get_online_projects(&self) -> Vec<ProjectInfo>
pub async fn get_online_projects(&self) -> Vec<ProjectInfo>
Get list of all online projects from in-memory state
Sourcepub async fn get_online_projects_with_current(
&self,
current_project_name: &str,
current_project_path: &Path,
current_db_path: &Path,
host_project: &ProjectInfo,
_port: u16,
) -> Vec<ProjectInfo>
pub async fn get_online_projects_with_current( &self, current_project_name: &str, current_project_path: &Path, current_db_path: &Path, host_project: &ProjectInfo, _port: u16, ) -> Vec<ProjectInfo>
Get list of all online projects Always includes the current Dashboard project plus all MCP-connected projects This is the single source of truth for project status