Functions
- add_
dependency - Add a dependency between two tasks after checking for circular dependencies.
- check_
circular_ dependency - Check if adding a dependency would create a circular dependency.
- get_
incomplete_ blocking_ tasks - Check if a task is blocked by any incomplete tasks