pub async fn get_blocking_tasks( pool: &SqlitePool, task_id: i64, ) -> Result<Vec<i64>>
Get all tasks that block a given task (dependencies)
pool
task_id
Vector of task IDs that must be completed before the given task can start