get_incomplete_blocking_tasks

Function get_incomplete_blocking_tasks 

pub async fn get_incomplete_blocking_tasks(
    pool: &SqlitePool,
    task_id: i64,
) -> Result<Option<Vec<i64>>>
Check if a task is blocked by any incomplete tasks

A task is blocked if any of its blocking tasks are not in ‘done’ status.

Arguments

  • pool - Database connection pool
  • task_id - ID of the task to check

Returns

  • Ok(Some(Vec<i64>)) with IDs of incomplete blocking tasks if blocked
  • Ok(None) if task is not blocked and can be started