Global Projects Registry
Manages a global list of all projects that have used Intent-Engine. This allows the Dashboard to show all known projects even when CLI is not running.
Structs
- Project
Entry - A registered project entry
- Projects
Registry - Global projects registry
Functions
- register_
project - Register a project in the global registry (convenience function)
- remove_
project - Remove a project from the global registry (convenience function)