Module common

Module common 

Common utilities for setup operations

Functions

create_backup
Create a backup of a file if it exists
find_ie_binary
Find the ie binary path
get_home_dir
Get the home directory
read_json_config
Read a JSON config file, or return empty object if it doesn’t exist
remove_backup
Remove a backup file
resolve_absolute_path
Resolve a path to absolute canonical form
restore_from_backup
Restore from a backup file
set_executable
Set executable permissions on Unix platforms
write_json_config
Write a JSON config file with pretty formatting