Module windows_console

Module windows_console 

Windows Console UTF-8 Support

This module provides utilities for handling console encoding on Windows. It automatically configures the console to use UTF-8 encoding for proper display and input of Chinese and other non-ASCII characters.

Functions

code_page_name
Get a user-friendly name for a Windows code page
get_console_code_page
get_console_input_code_page
is_console_input_utf8
is_console_utf8
setup_windows_console
Setup Windows console for UTF-8 output (no-op on non-Windows platforms)