TaskCommands

Enum TaskCommands 

pub enum TaskCommands {
    Add {
        name: String,
        parent: Option<i64>,
        spec_stdin: bool,
    },
    Get {
        id: i64,
        with_events: bool,
    },
    Update {
        id: i64,
        name: Option<String>,
        parent: Option<i64>,
        status: Option<String>,
        complexity: Option<i32>,
        priority: Option<String>,
        spec_stdin: bool,
    },
    Del {
        id: i64,
    },
    List {
        status: Option<String>,
        parent: Option<String>,
    },
    Start {
        id: i64,
        with_events: bool,
    },
    Done,
    PickNext {
        format: String,
    },
    SpawnSubtask {
        name: String,
        spec_stdin: bool,
    },
    DependsOn {
        blocked_task_id: i64,
        blocking_task_id: i64,
    },
    Context {
        task_id: Option<i64>,
    },
}

Variants



Add

Add a new task

Fields

name: String

Task name

parent: Option<i64>

Parent task ID

spec_stdin: bool

Read spec from stdin



Get

Get a task by ID

Fields

id: i64

Task ID

with_events: bool

Include events summary



Update

Update a task

Fields

id: i64

Task ID

name: Option<String>

New task name

parent: Option<i64>

New parent task ID

status: Option<String>

New status

complexity: Option<i32>

Task complexity (1-10)

priority: Option<String>

Task priority (critical, high, medium, low)

spec_stdin: bool

Read spec from stdin



Del

Delete a task

Fields

id: i64

Task ID



List

List tasks with filters

Examples: ie task list # List all tasks ie task list todo # List todo tasks ie task list doing # List doing tasks ie task list done # List done tasks

Fields

status: Option<String>

Filter by status (todo, doing, done)

parent: Option<String>

Filter by parent ID (use “null” for no parent)



Start

Start a task (atomic: update status + set current)

Fields

id: i64

Task ID

with_events: bool

Include events summary



Done

Complete the current focused task (atomic: check children + update status + clear current) This command only operates on the current_task_id. It will:

  • Check all subtasks are done

  • Update the task status to done

  • Clear the current_task_id

    Prerequisites: A task must be set as current (via current --set <ID>)



PickNext

Intelligently recommend the next task to work on

This command uses a context-aware priority model to recommend a single task:

  1. First priority: ‘doing’ subtasks of current focused task
  2. Second priority: ‘todo’ subtasks of current focused task
  3. Third priority: Top-level ‘doing’ tasks
  4. Fourth priority: Top-level ‘todo’ tasks

Within the same priority level, ‘doing’ tasks are prioritized over ‘todo’ tasks. The command is non-interactive and does not modify task status.

Fields

format: String

Output format (text or json)



SpawnSubtask

Create a subtask under current task and switch to it

Fields

name: String

Subtask name

spec_stdin: bool

Read spec from stdin



DependsOn

Switch to a specific task (atomic: update to doing + set current) Add a dependency between tasks

Creates a dependency where BLOCKED_TASK depends on BLOCKING_TASK. The BLOCKING_TASK must be completed before BLOCKED_TASK can be started.

Example: task depends-on 42 41 means Task 42 depends on Task 41 (Task 41 must be done before Task 42 can start)

Fields

blocked_task_id: i64

Task ID that has the dependency (blocked task)

blocking_task_id: i64

Task ID that must be completed first (blocking task)



Context

Get task context (ancestors, siblings, children)

Shows the full family tree of a task to understand its strategic context. If no task ID is provided, uses the current focused task.

Fields

task_id: Option<i64>

Task ID (optional, uses current task if omitted)