Structs
- Approval
Response - Response for creating a task approval
- Date
Range - Dependency
- Done
Task Response - Event
- Events
Summary - NoFocus
Response - Response when no task is focused
- Paginated
Search Results - Paginated search results across tasks and events
- Paginated
Tasks - Paginated task query results
- Parent
Task Info - Parent task info for spawn response
- Pick
Next Response - Report
- Report
Summary - Spawn
Subtask Response - Response for spawn-subtask command - includes subtask and parent info
- Status
Breakdown - Status
Response - Response for ie status command - the “spotlight” view of a task
- Subtask
Info - Subtask info for spawn response
- Task
- Task
Approval - Task approval record for human task authorization AI must provide the passphrase to complete a human-owned task
- Task
Brief - Simplified task info for siblings/descendants in status response
- Task
Context - Response for task_context - provides the complete family tree of a task
- Task
Dependencies - Dependency information for a task
- Task
Search Result - Task
With Events - Workspace
State - Workspace
Stats - Workspace statistics (aggregated counts without loading tasks)
- Workspace
Status
Enums
- Next
Step Suggestion - Search
Result - Unified search result that can represent either a task or event match
- Task
Sort By - Sort order for task queries