Module dependencies

Module dependencies 

Functions

add_dependency
Add a dependency between two tasks after checking for circular dependencies.
check_circular_dependency
Check if adding a dependency would create a circular dependency.
get_blocked_tasks
Get all tasks that are blocked by a given task
get_blocking_tasks
Get all tasks that block a given task (dependencies)
get_incomplete_blocking_tasks
Check if a task is blocked by any incomplete tasks