Module global_projects

Module global_projects 

Global Projects Registry

Manages a global list of all projects that have used Intent-Engine. This allows the Dashboard to show all known projects even when CLI is not running.

Structs

ProjectEntry
A registered project entry
ProjectsRegistry
Global projects registry

Functions

register_project
Register a project in the global registry (convenience function)
remove_project
Remove a project from the global registry (convenience function)