Pure validation functions for plan execution.
Shared between SQLite PlanExecutor and Neo4j Neo4jPlanExecutor.
All functions are stateless — no database access.
Functions
- detect_
circular_ dependencies - Detect circular dependencies using Tarjan’s SCC algorithm.
- tarjan_
scc - Tarjan’s algorithm for finding strongly connected components.
- validate_
batch_ single_ doing - Validate that at most one task in the batch has status=‘doing’.
- validate_
dependencies - Validate that all dependency references exist within the plan.