Common utilities for setup operations
Functions
- create_
backup - Create a backup of a file if it exists
- find_
ie_ binary - Find the ie binary path
- get_
home_ dir - Get the home directory
- read_
json_ config - Read a JSON config file, or return empty object if it doesn’t exist
- remove_
backup - Remove a backup file
- resolve_
absolute_ path - Resolve a path to absolute canonical form
- restore_
from_ backup - Restore from a backup file
- set_
executable - Set executable permissions on Unix platforms
- write_
json_ config - Write a JSON config file with pretty formatting