TaskManager

Struct TaskManager 

pub struct TaskManager<'a> { /* private fields */ }

Implementations

Source

impl<'a> TaskManager<'a>

pub fn new(pool: &'a SqlitePool) -> Self

pub async fn add_task( &self, name: &str, spec: Option<&str>, parent_id: Option<i64>, ) -> Result<Task>

Add a new task

pub async fn get_task(&self, id: i64) -> Result<Task>

Get a task by ID

pub async fn get_task_with_events(&self, id: i64) -> Result<TaskWithEvents>

Get a task with events summary

pub async fn update_task( &self, id: i64, name: Option<&str>, spec: Option<&str>, parent_id: Option<Option<i64>>, status: Option<&str>, complexity: Option<i32>, priority: Option<i32>, ) -> Result<Task>

Update a task

pub async fn delete_task(&self, id: i64) -> Result<()>

Delete a task

pub async fn find_tasks( &self, status: Option<&str>, parent_id: Option<Option<i64>>, ) -> Result<Vec<Task>>

Find tasks with optional filters

pub async fn search_tasks(&self, query: &str) -> Result<Vec<TaskSearchResult>>

Search tasks using full-text search (FTS5) Returns tasks with match snippets showing highlighted keywords

pub async fn start_task( &self, id: i64, with_events: bool, ) -> Result<TaskWithEvents>

Start a task (atomic: update status + set current)

pub async fn done_task(&self) -> Result<DoneTaskResponse>

Complete the current focused task (atomic: check children + update status + clear current) This command only operates on the current_task_id. Prerequisites: A task must be set as current

pub async fn switch_to_task(&self, id: i64) -> Result<SwitchTaskResponse>

Switch to a specific task (atomic: update status to doing + set as current) If the task is not in ‘doing’ status, it will be transitioned to ‘doing’ Returns response with previous task info (if any) and current task info

pub async fn spawn_subtask( &self, name: &str, spec: Option<&str>, ) -> Result<SpawnSubtaskResponse>

Create a subtask under the current task and switch to it (atomic operation) Returns error if there is no current task Returns response with subtask info and parent task info

pub async fn pick_next_tasks( &self, max_count: usize, capacity_limit: usize, ) -> Result<Vec<Task>>

Intelligently pick tasks from ‘todo’ and transition them to ‘doing’ Returns tasks that were successfully transitioned

Arguments
  • max_count - Maximum number of tasks to pick
  • capacity_limit - Maximum total number of tasks allowed in ‘doing’ status
Logic
  1. Check current ‘doing’ task count
  2. Calculate available capacity
  3. Select tasks from ‘todo’ (prioritized by: priority DESC, complexity ASC)
  4. Transition selected tasks to ‘doing’
pub async fn pick_next(&self) -> Result<PickNextResponse>

Intelligently recommend the next task to work on based on context-aware priority model.

Priority logic:

  1. First priority: Subtasks of the current focused task (depth-first)
  2. Second priority: Top-level tasks (breadth-first)
  3. No recommendation: Return appropriate empty state

This command does NOT modify task status.